<?php

namespace Baqend\WordPress\Model;

/**
 * Class Stats created on 2018-06-27.
 *
 * @author Konstantin Simon Maria Möllers
 * @author Kevin Twesten
 * @package Baqend\WordPress\Model
 */
class Stats {

    /**
     * @var string
     */
    public $app_name;

    /**
     * @var bool
     */
    public $app_exceeded;

    /**
     * @var int
     */
    public $fix_price;

    /**
     * @var int
     */
    public $price_max;

    /**
     * @var int
     */
    public $price_now;

    /**
     * @var int
     */
    public $requests_max;

    /**
     * @var int
     */
    public $requests_now;

    /**
     * @var int
     */
    public $traffic_max;

    /**
     * @var int
     */
    public $traffic_now;

    /**
     * @var int
     */
    public $price_percent;

    /**
     * @var int
     */
    public $requests_percent;

    /**
     * @var int
     */
    public $traffic_percent;

    /**
     * @var int
     */
    public $percent;

    /**
     * Stats constructor.
     *
     * @param array $data
     */
    public function __construct( array $data ) {
        if ( ! $data || isset( $data['appExceeded'] ) ) {
            $this->app_exceeded = true;
            $this->price_max    = 0;
            $this->percent      = 100;

            return;
        }

        $this->app_name         = $data['appName'];
        $this->fix_price        = $data['fixPrice'];
        $this->price_max        = $data['priceMax'];
        $this->price_now        = $data['priceNow'];
        $this->price_percent    = $this->percent( $this->price_now, $this->price_max );
        $this->requests_max     = $data['requestsMax'];
        $this->requests_now     = $data['requestsNow'];
        $this->requests_percent = $this->percent( $this->requests_now, $this->requests_max );
        $this->traffic_max      = $data['trafficMax'];
        $this->traffic_now      = $data['trafficNow'];
        $this->traffic_percent  = $this->percent( $this->traffic_now, $this->traffic_max );
        $this->percent          = max( $this->requests_max > 0 ? $this->requests_now / $this->requests_max : 0, $this->traffic_max > 0 ? $this->traffic_now / $this->traffic_max : 0 );
        $this->app_exceeded     = false;
    }

    /**
     * @return bool
     */
    public function is_free() {
        return $this->price_max === 0;
    }

    /**
     * @return bool
     */
    public function is_limited() {
        return $this->price_max > - 1;
    }

    /**
     * @return bool
     */
    public function is_unlimited() {
        return $this->price_max === - 1;
    }

    /**
     * @return bool
     */
    public function is_exceeded() {

        return $this->app_exceeded;
    }

    /**
     * @param int $now
     * @param int $max
     *
     * @return int
     */
    private function percent( $now, $max ) {
        if ( $max <= 0 ) {
            return - 1;
        }

        return (int) round( 100 * $now / $max );
    }
}
