<?php

namespace Baqend\WordPress\Service;

use Baqend\SDK\Client\RestClient;
use Baqend\WordPress\Model\Stats;
use Baqend\WordPress\Plugin;

/**
 * Service to handle statistical data
 *
 * @package Baqend\WordPress\Service
 * @author Brigitte Kwasny
 * Date: 10.07.2018
 */
class StatsService {

    /**
     * @var Plugin
     */
    private $plugin;

    /**
     * @var Stats|null
     */
    private $cached_stats;

    public function __construct( Plugin $plugin ) {
        $this->plugin       = $plugin;
        $this->cached_stats = null;
    }

    /**
     * @return Stats|null
     */
    public function load_stats() {
        if ( ! $this->plugin->app_name ) {
            return null;
        }

        if ( $this->cached_stats !== null ) {
            return $this->cached_stats;
        }

        $app_name      = $this->plugin->app_name;
        $authorization = $this->plugin->options->get( 'authorization' );
        if ( $authorization === null ) {
            $authorization = $this->plugin->options->get( 'api_token' );
            if ( $authorization === null ) {
                return null;
            }
        }
        $client      = $this->plugin->baqend->getClient();
        $rest_client = new RestClient( 'bbq', $this->plugin->serializer, $client );

        $request = $rest_client->createRequest()
                               ->asPost()
                               ->withPath( '/code/wordpressStats' )
                               ->withJsonBody( [
                                   'appName'       => $app_name,
                                   'authorization' => $authorization,
                               ] )
                               ->build();
        try {
            $response = $client->sendSyncRequest( $request );

            return new Stats( $this->plugin->serializer->decode( $response->getBody(), 'json' ) );
        } catch ( \Exception $e ) {
            return null;
        }
    }
}
