<template id="registration-template">
  <form name="registration" @submit.prevent="submit">
    <div id="registration-error" class="updated error is-dismissible" v-if="errorDisplayed">
      <p><?php _e('Please provide a valid e-mail address.', 'baqend') ?></p>
      <button type="button" class="notice-dismiss"><span class="screen-reader-text"><?php _e('dismiss') ?></span></button>
    </div>

    <div class="metabox-holder">
      <div class="postbox">
        <div class="inside">
          <h2 class="title"><?php _e('Access to Baqend Cloud', 'baqend') ?></h2>
          <p><?php _e('First, create an access for the Baqend Cloud with your e-mail. You need it to use Baqend’s performance features.', 'baqend') ?></p>

          <table class="form-table">
            <tr>
              <th><label for="registration-username"><?php _e('E-Mail', 'baqend') ?></label></th>
              <td>
                <input type="text" name="username" id="registration-username" class="regular-text" v-model="username" :disabled="disabled" required autocomplete="email">
                <p class="description"><?php _e('Enter a valid e-mail address you will use to acess Baqend Cloud.', 'baqend') ?></p>
              </td>
            </tr>
          </table>

          <p><a href="#" @click.prevent="handleShowLogin" id="link-login"><?php _e('I already have an access to Baqend Cloud', 'baqend'); ?></a></p>
          <p><a href="#" @click.prevent="handleShowLoginWithToken" id="link-login-with-token"><?php _e('I have a Baqend Token', 'baqend'); ?></a></p>

          <p><?php echo str_replace('%terms%', 'https://dashboard.baqend.com/terms',
              str_replace('%privacy%', 'https://dashboard.baqend.com/privacy',
                __('By getting access to Baqend Cloud, you agree to Baqend’s <a href="%terms%" target="_blank">Terms of Service</a> and <a href="%privacy%" target="_blank">Privacy Policy</a>.', 'baqend'))); ?></p>
          <?php submit_button(__('Continue', 'baqend'), 'primary', 'baqendRegister', false, [':disabled' => 'disabled']); ?>
          <div class="spinner spinner-show" v-if="disabled"></div>
        </div>
      </div>
    </div>
  </form>
</template>

<template id="login-template">
  <form name="login" @submit.prevent="submit">
    <div id="login-error" class="updated error is-dismissible" v-if="errorDisplayed">
      <p><?php _e('Your credentials were not correct. Please try again.', 'baqend') ?></p>
      <button type="button" class="notice-dismiss"><span class="screen-reader-text"><?php _e('dismiss') ?></span></button>
    </div>

    <div class="metabox-holder">
      <div class="postbox">
        <div class="inside">
          <h2 class="title"><?php _e('Log in to Baqend', 'baqend') ?></h2>
          <p><?php _e('Log in to Baqend with the credentials of an existing Baqend account.', 'baqend') ?></p>

          <table class="form-table">
            <tr>
              <th><label for="form-username"><?php _e('E-Mail', 'baqend') ?></label></th>
              <td>
                <input type="text" name="username" id="form-username" class="regular-text" v-model="username" :disabled="disabled" required>
                <p class="description"><?php _e('The e-mail you use to login to Baqend.', 'baqend') ?></p>
              </td>
            </tr>
            <tr>
              <th><label for="form-password"><?php _e('Password', 'baqend') ?></label></th>
              <td>
                <input type="password" name="password" id="form-password" class="regular-text" v-model="password" :disabled="disabled" required>
                <p class="description"><?php _e('The password you use to login to Baqend.', 'baqend') ?></p>
              </td>
            </tr>
          </table>

          <p><a href="#" @click.prevent="handleShowLoginWithToken" id="link-login-with-token-2"><?php _e('Login with token', 'baqend'); ?></a></p>
          <p><a href="#" @click.prevent="handleShowRegistration" id="link-register"><?php _e('I don’t have an access to Baqend Cloud yet', 'baqend'); ?></a></p>

          <?php submit_button(__('Log In', 'baqend'), 'primary', 'baqendLogin', false); ?>
          <div class="spinner spinner-show" v-if="disabled"></div>
        </div>
      </div>
    </div>
  </form>
</template>

<template id="login-with-token-template">
  <form name="login-with-token" @submit.prevent="submit">
    <div id="login-error" class="updated error is-dismissible" v-if="errorDisplayed">
      <p><?php _e('Your token was not correct. Please try again.', 'baqend') ?></p>
      <button type="button" class="notice-dismiss"><span class="screen-reader-text"><?php _e('dismiss') ?></span></button>
    </div>

    <div class="metabox-holder">
      <div class="postbox">
        <div class="inside">
          <h2 class="title"><?php _e('Log in to Baqend', 'baqend') ?></h2>
          <p><?php _e('Alternatively, log in to Baqend with the token of an existing Baqend account.', 'baqend') ?></p>

          <table class="form-table">
            <tr>
              <th><label for="form-token"><?php _e('Baqend Token', 'baqend') ?></label></th>
              <td>
                <input type="text" name="token" id="form-token" class="regular-text" v-model="token" :disabled="disabled" required>
                <p class="description"><?php _e('The token you can find in your Baqend Dashboard.', 'baqend') ?></p>
              </td>
            </tr>
          </table>

          <p><a href="#" @click.prevent="handleShowLogin" id="link-register"><?php _e('Login with credentials', 'baqend'); ?></a></p>
          <p><a href="#" @click.prevent="handleShowRegistration" id="link-register"><?php _e('I don’t have an access to Baqend Cloud yet', 'baqend'); ?></a></p>

          <?php submit_button(__('Log In', 'baqend'), 'primary', 'baqendLogin', false); ?>
          <div class="spinner spinner-show" v-if="disabled"></div>
        </div>
      </div>
    </div>
  </form>
</template>

<template id="select-app-template">
  <form name="select-app" @submit.prevent="submit">
    <div class="metabox-holder">
      <div class="postbox">
        <div class="inside">
          <h2 class="title"><?php _e('Choose an app', 'baqend') ?></h2>
          <p><?php _e('Please select one of your apps below. Your WordPress blog will then be hosted on the selected app.', 'baqend') ?></p>

          <table class="form-table">
            <tr>
              <th><label for="form-app-name"><?php _e('App Name', 'baqend') ?></label></th>
              <td>
                <select name="app-name" id="form-app-name" :disabled="disabled" @change.prevent="updateSelection($event.target.value)">
                  <option disabled :selected="!value"><?php _e('Select an app…', 'baqend'); ?></option>
                  <option v-for="app in apps" :value="app.id" :selected="value === app">{{app.name}}</option>
                </select>
              </td>
            </tr>
          </table>

          <?php submit_button(__('Select App', 'baqend'), 'primary', 'baqendSelectApp', false, [':disabled' => 'disabled || !value']); ?>
          <button class="button" @click.prevent="logout" :disabled="disabled"><?php _e('Not {{username}}? Log Out', 'baqend'); ?></button>
          <div class="spinner spinner-show" v-if="disabled"></div>
        </div>
      </div>
    </div>
  </form>
</template>
